@@ -34,13 +34,12 @@
 #include <meta/errors.h>
 
 #include <cogl/cogl.h>
-#include <cogl/cogl-wayland-server.h>
 #include <clutter/clutter.h>
 
 #include <gdk/gdk.h>
 #include <gdk/gdkx.h>
 
-#include "meta-backend.h"
+#include "meta-backend-private.h"
 
 #include "meta-cursor-private.h"
 #include "meta-cursor-tracker-private.h"
@@ -48,8 +47,8 @@
 G_DEFINE_TYPE (MetaCursorTracker, meta_cursor_tracker, G_TYPE_OBJECT);
 
 enum {
-    CURSOR_CHANGED,
-    LAST_SIGNAL
+  CURSOR_CHANGED,
+  LAST_SIGNAL
 };
 
 static guint signals[LAST_SIGNAL];
@@ -62,7 +61,7 @@ get_displayed_cursor (MetaCursorTracker *tracker)
   if (!tracker->is_showing)
     return NULL;
 
-  if (display->grab_op == META_GRAB_OP_NONE)
+  if (meta_display_windows_are_interactable (display))
     {
       if (tracker->has_window_cursor)
         return tracker->window_cursor;
