@@ -94,6 +94,15 @@ struct _MetaPluginClass
   void (*minimize)         (MetaPlugin         *plugin,
                             MetaWindowActor    *actor);
 
+  /**
+   * MetaPluginClass::unminimize:
+   * @actor: a #MetaWindowActor
+   *
+   * Virtual function called when the window represented by @actor is unminimized.
+   */
+  void (*unminimize)       (MetaPlugin         *plugin,
+                            MetaWindowActor    *actor);
+
   /**
    * MetaPluginClass::maximize:
    * @actor: a #MetaWindowActor
@@ -372,6 +381,10 @@ void
 meta_plugin_minimize_completed (MetaPlugin      *plugin,
                                 MetaWindowActor *actor);
 
+void
+meta_plugin_unminimize_completed (MetaPlugin      *plugin,
+                                  MetaWindowActor *actor);
+
 void
 meta_plugin_maximize_completed (MetaPlugin      *plugin,
                                 MetaWindowActor *actor);
